' '********************************************************************************************
' Description	: Recognizes a word or phrase in a recorded file and prints out the recognition results
'		: See the folder "Speech Recognition and Text to Speech" in the Callmaster\DOC folder for more details
' File Type	: CallMaster script file by SpeechSoft, Inc. 04/05/05
' File Name	: RecognizeTree.bas
' Format	: Recognize <AudioFileIn> <TexttoRecognize> <ASRType> <RecognizedWords> <WordCount> <wValue> <wValueString> <ASROK> <RecognitionResultTree>	
'			AudioFileIn 	- [string,input] is name of file with path that has the recording
'			TexttoRecognize	- [string,input] Contains the words to be recognized seperated by commas or 
'					  a file Name as determined by the Type parameter
'			ASRType		- [string,in] "TEXT"|"FILE"|"XMLFILE" where 
'					  TEXT means the prior field has the actual word list, 
'				          FILE means it has a file name that has the list and 
'					  XMLFILE means it has a name of an XML file that has the grammar
'			RecognizedWords - [string,output] The words that were recognized
'			WordCount 	- [integer,output] Number of words recognized
'			wValue 		- [integer,output] contains the XML VAL tag/attribute eg VAL="32"
'					  the XML PropertyID of the word recognized
'			wValueString 	- [string,output] Returns the XML VALSTR tag/attribute for the recognizd words/Phrases.
'			ASROK 		- [int,output] Returns the status of the recognize process. 1 - Pass or 0 - Fail.  
'					  Determines whether the returned values are valid.'
'			RecognitionResultTree - [string,output] Returns the Speech Engines recognition grammar tree with the 
'						    XML grammar fields seperated by dashed '-' Phrase elements are seperated by comas ','.
' '*********************************************************************************************
Program

	Print "RecognizeTree Test Script started"

' Initialize variables
	Prompt = 100
	RecTime = 180
	t = "*"
	a = ""
	recfileid = 0

' Record words spoken by the caller that need to be recognized.
	' Plays prompt 100 (Press * to stop recording) to instruct caller, Then.
	' Records file and places speechfile id in integer variable recfileid.  

	Record recfileid Prompt RecTime a t e d

	IntegerToString audiofileID recfileid
	ptext = "fileID  = " & audiofileID
	Print ptext

' Rename recording to file name from recording number to be used in the Recognize command
	FileIDToName AudioFileIn recfileid

' Now setup for recognition of the recorded file which needs to be in the Callmaster\Data folder

	TexttoRecognize = "recognizetree.xml"
	WordCount = 0
	wValue = 0
	ASRType = "XMLFILE"
	'ASRType = "FILE"
	ASROK = 0

'Recognize The words in the TexttoRecognize field if they were spoken

	Recognize AudioFileIn TexttoRecognize ASRType RecognizedWords WordCount wValue wValueString ASROK ResultTree

'Test validity of the recognition results 1-Pass, 0-Fail
	If ASROK = 0 Then
		Print " *** ASR Recognize failed!"
		RecognizedWords = " ** Failed ** "
	Else

' Print out the recogition results

		ptext = "ASR RecognizedWord = " & RecognizedWords
		Print ptext
		IntegerToString pvalue wValue 
		ptext = "ASR Result = " & pvalue 
		Print ptext
		IntegerToString pvalue WordCount
		ptext = "ASR WordCount = " & pvalue 
		Print ptext
		ptext = "ASR wValueString = " & wValueString
		Print ptext
		ptext = "Speech Recognition Result Tree> " & ResultTree
		Print ptext 

	EndIf


EndProgram
